@@ -1,5 +1,5 @@
 /*
- * $Id: daemon.c 6198 2012-03-07 10:07:35Z matthijs $
+ * $Id: daemon.c 6307 2012-05-04 09:36:03Z jerry $
  *
  * Copyright (c) 2008-2009 Nominet UK. All rights reserved.
  *
@@ -228,16 +228,9 @@ main(int argc, char *argv[]){
 
     config.uid = geteuid();
     config.gid = getegid();
+	config.pid = getpid();
 
-    /* write the pidfile */
-    config.pid = getpid();
-    if (writepid(&config) == -1) {
-        log_msg(&config, LOG_ERR, "cannot write the pidfile %s: %s",
-                config.pidfile, strerror(errno));
-        exit(1);
-    }
-
-    atexit(exit_function);
+	atexit(exit_function);
 
     log_msg(&config, LOG_NOTICE, "%s started (version %s), pid %d", PACKAGE_NAME, PACKAGE_VERSION, 
             (int) config.pid);
