@@ -1,5 +1,5 @@
 /*
- * $Id: enforcer.c 5838 2011-11-08 14:28:05Z sion $
+ * $Id: enforcer.c 6379 2012-06-05 08:52:37Z jerry $
  *
  * Copyright (c) 2008-2009 Nominet UK. All rights reserved.
  *
@@ -101,7 +101,6 @@ server_main(DAEMONCONFIG *config)
     policy = KsmPolicyAlloc();
     if (policy == NULL) {
         log_msg(config, LOG_ERR, "Malloc for policy struct failed");
-        unlink(config->pidfile);
         exit(1);
     }
     kaspSetPolicyDefaults(policy, NULL);
@@ -110,7 +109,6 @@ server_main(DAEMONCONFIG *config)
     status = ReadConfig(config , 0);
     if (status != 0) {
         log_msg(config, LOG_ERR, "Error reading config");
-        unlink(config->pidfile);
         exit(1);
     }
 
@@ -150,13 +148,26 @@ server_main(DAEMONCONFIG *config)
                         log_msg(config, LOG_ERR, "hsm_open() result: %d", result);
                 }
             }
-            unlink(config->pidfile);
             exit(1);
         }
         log_msg(config, LOG_INFO, "HSM opened successfully.");
         ctx = hsm_create_context();
     /*}*/
 
+    log_msg(config, LOG_INFO, "Checking database connection...");
+    if (kaspTryConnect(config, &dbhandle)) {
+        log_msg(config, LOG_ERR, "Database connection failed");
+        exit(1);
+    }
+    log_msg(config, LOG_INFO, "Database connection ok.");
+
+    /* Create pidfile as late as possible to report start up error */
+	if (writepid(config) == -1) {
+		log_msg(config, LOG_ERR, "cannot write the pidfile %s: %s",
+			config->pidfile, strerror(errno));
+		exit(1);
+	}
+
     while (1) {
 
         /* Read the config file */
@@ -235,7 +246,9 @@ server_main(DAEMONCONFIG *config)
         }
 
         /* Communicate zones to the signer */
+        KsmParameterCollectionCache(1); /* Enable caching of policy parameters while in do_communication() */
         do_communication(config, policy);
+        KsmParameterCollectionCache(0);
         
         DbFreeResult(handle);
 
