@@ -1,5 +1,5 @@
 /*
- * $Id: ksmutil.h 5994 2012-01-03 16:14:24Z sion $
+ * $Id: ksmutil.h 6292 2012-04-27 09:39:55Z sion $
  *
  * Copyright (c) 2008-2009 Nominet UK. All rights reserved.
  *
@@ -99,7 +99,7 @@ int keyRoll(int zone_id, int policy_id, int key_type);
 int get_policy_name_from_id(KSM_ZONE *zone);
 int append_zone(xmlDocPtr doc, KSM_ZONE *zone);
 int ShellQuoteString(const char* string, char* buffer, size_t buflen);
-int extract_signconf(const char* zonelist_filename, const char* o_zone, char** signconf);
+int rename_signconf(const char* zonelist_filename, const char* o_zone);
 
 #ifdef __cplusplus
 }
