@@ -1,5 +1,5 @@
 /*
- * $Id: ksm_import.c 4656 2011-03-25 08:51:54Z rb $
+ * $Id: ksm_import.c 5838 2011-11-08 14:28:05Z sion $
  *
  * Copyright (c) 2008-2009 Nominet UK. All rights reserved.
  *
@@ -347,6 +347,8 @@ int KsmImportAudit(int policy_id, const char* audit_contents)
  *          state to set key to
  *      time
  *          timestamp of entry into state given
+ *      fixDate
+ *             set to 1 if the retire date should be fixed
  *
  *      DB_ID* id (returned)
  *          ID of the created entry.  This will be undefined on error.
@@ -355,7 +357,7 @@ int KsmImportAudit(int policy_id, const char* audit_contents)
  *      int
  *          Status return.  0=> Success, non-zero => error.
 -*/
-int KsmImportKeyPair(int policy_id, const char* HSMKeyID, int smID, int size, int alg, int state, const char* time, DB_ID* id)
+int KsmImportKeyPair(int policy_id, const char* HSMKeyID, int smID, int size, int alg, int state, const char* time, int fixDate, DB_ID* id)
 {
     unsigned long rowid;			/* ID of last inserted row */
     int         status = 0;         /* Status return */
@@ -372,6 +374,9 @@ int KsmImportKeyPair(int policy_id, const char* HSMKeyID, int smID, int size, in
         StrAppend(&columns, ", ");
         StrAppend(&columns, KsmKeywordStateValueToName(state));
     }
+	if (state == KSM_STATE_ACTIVE && fixDate == 1) {
+        StrAppend(&columns, ", fixedDate");
+    }
 
     sql = DisSpecifyInit("keypairs", columns);
     DisAppendInt(&sql, policy_id);
@@ -381,6 +386,9 @@ int KsmImportKeyPair(int policy_id, const char* HSMKeyID, int smID, int size, in
     DisAppendInt(&sql, alg);
     if (state == KSM_STATE_GENERATE) {
         DisAppendString(&sql, time);
+    }
+	if (state == KSM_STATE_ACTIVE && fixDate == 1) {
+        DisAppendInt(&sql, fixDate);
     }
     DisEnd(&sql);
 
@@ -400,8 +408,6 @@ int KsmImportKeyPair(int policy_id, const char* HSMKeyID, int smID, int size, in
 		}
     }
 
-    /* TODO Fix retire time if needed */
-
     return status;
 }
 
