@@ -1,5 +1,5 @@
 /*
- * $Id: hsmutil.c 6123 2012-02-02 09:04:39Z rb $
+ * $Id: hsmutil.c 6190 2012-02-28 15:29:48Z rb $
  *
  * Copyright (c) 2009 .SE (The Internet Infrastructure Foundation).
  * Copyright (c) 2009 NLNet Labs.
@@ -347,6 +347,8 @@ cmd_dnskey (int argc, char *argv[])
 
     if (!key) {
         printf("Key not found: %s\n", id);
+        free(name);
+        free(id);
         return -1;
     }
 
@@ -361,6 +363,8 @@ cmd_dnskey (int argc, char *argv[])
     hsm_sign_params_free(sign_params);
     ldns_rr_free(dnskey_rr);
     hsm_key_free(key);
+    free(name);
+    free(id);
 
     return 0;
 }
