@@ -1,5 +1,5 @@
 /*
- * $Id: adfile.c 6125 2012-02-02 09:30:21Z matthijs $
+ * $Id: adfile.c 6244 2012-04-03 13:56:27Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -450,7 +450,7 @@ adfile_write(struct zone_struct* zone, const char* filename)
     /* [end] sanity parameter checking */
 
     /* [start] write zone */
-    tmpname = ods_build_path(filename, ".tmp", 0);
+    tmpname = ods_build_path(filename, ".tmp", 0, 0);
     fd = ods_fopen(tmpname, NULL, "w");
     if (fd) {
         status = zone_print(fd, adzone);
