@@ -1,5 +1,5 @@
 /*
- * $Id: cmdhandler.c 6112 2012-01-30 15:12:33Z matthijs $
+ * $Id: cmdhandler.c 6312 2012-05-08 09:54:27Z jerry $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -178,8 +178,11 @@ cmdhandler_handle_cmd_update(int sockfd, cmdhandler_type* cmdc,
         if (zl_changed == ODS_STATUS_UNCHANGED) {
             lock_basic_unlock(&cmdc->engine->zonelist->zl_lock);
             (void)snprintf(buf, ODS_SE_MAXLINE, "Zone list has not changed."
-                "\n");
+                " Signer configurations updated.\n");
             ods_writen(sockfd, buf, strlen(buf));
+
+            engine_update_zones(cmdc->engine);
+            ods_log_debug("[%s] signer configurations updated", cmdh_str);
         } else if (zl_changed == ODS_STATUS_OK) {
             (void)snprintf(buf, ODS_SE_MAXLINE, "Zone list updated: %i "
             "removed, %i added, %i updated.\n",
@@ -208,7 +211,8 @@ cmdhandler_handle_cmd_update(int sockfd, cmdhandler_type* cmdc,
         /* [LOCK] zonelist */
         zone = zonelist_lookup_zone_by_name(cmdc->engine->zonelist, tbd,
             LDNS_RR_CLASS_IN);
-        /* If this zone is just added, don't update (it might not have a task yet) */
+        /* If this zone is just added, don't update (it might not have a
+         * task yet) */
         if (zone && zone->just_added) {
             zone = NULL;
         }
@@ -377,7 +381,7 @@ cmdhandler_handle_cmd_sign(int sockfd, cmdhandler_type* cmdc, const char* tbd)
 static void
 unlink_backup_file(const char* filename, const char* extension)
 {
-    char* tmpname = ods_build_path(filename, extension, 0);
+    char* tmpname = ods_build_path(filename, extension, 0, 1);
     ods_log_debug("[%s] unlink file %s", cmdh_str, tmpname);
     unlink(tmpname);
     free((void*)tmpname);
