@@ -1,5 +1,5 @@
 /*
- * $Id: engine.c 6162 2012-02-13 12:33:26Z jerry $
+ * $Id: engine.c 6238 2012-04-03 09:53:56Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -884,7 +884,7 @@ engine_update_zones(engine_type* engine)
             /* zone fetcher enabled? */
             zone->fetch = (engine->config->zonefetch_filename != NULL);
             lock_basic_unlock(&zone->zone_lock);
-        } else if (zone->just_updated) {
+        } else { /* always try to update signconf */
             lock_basic_lock(&zone->zone_lock);
             ods_log_assert(zone->task);
             zone->just_updated = 0;
