@@ -1,5 +1,5 @@
 /*
- * $Id: ods-signer.c 6134 2012-02-02 14:15:32Z matthijs $
+ * $Id: ods-signer.c 6307 2012-05-04 09:36:03Z jerry $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -87,7 +87,7 @@ max(int a, int b)
  * Interface.
  *
  */
-static void
+static int
 interface_run(FILE* fp, int sockfd, char* cmd)
 {
     int maxfdp1 = 0;
@@ -133,7 +133,7 @@ interface_run(FILE* fp, int sockfd, char* cmd)
 
         if (cmd && cmd_written && cmd_response) {
             /* normal termination */
-            return;
+            return 0;
         }
 
         if (FD_ISSET(sockfd, &rset)) {
@@ -148,17 +148,17 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                 if (n < 0) {
                     /* error occurred */
                     fprintf(stderr, "error: %s\n", strerror(errno));
-                    exit(1);
+                    return 1;
                 } else {
                     /* n==0 */
                     if (stdineof == 1) {
                         /* normal termination */
-                        return;
+                        return 0;
                     } else {
                         /* weird termination */
                         fprintf(stderr, "signer engine terminated "
                                 "prematurely\n");
-                        exit(1);
+                        return 1;
                     }
                 }
             }
@@ -168,9 +168,8 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                     /* not enough data received */
                     fprintf(stderr, "not enough response data received "
                             "from daemon.\n");
-                    exit(1);
+                    return 1;
                 }
-
                 /* n >= SE_CLI_CMDLEN : and so it is safe to do buffer
                     manipulations below. */
                 if (strncmp(buf+n-SE_CLI_CMDLEN,"\ncmd> ",SE_CLI_CMDLEN) == 0) {
@@ -207,8 +206,8 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                 /* written+ret < n : means partial write, requires us to loop... */
             }
             if (ods_strcmp(buf, ODS_SE_STOP_RESPONSE) == 0 || cmd_response) {
-                fprintf(stderr, "\n");
-                return;
+                fprintf(stdout, "\n");
+                return 0;
             }
         }
 
@@ -222,7 +221,7 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                 if (ret != 0) {
                     fprintf(stderr, "shutdown failed: %s\n",
                         strerror(errno));
-                    exit(1);
+                    return 1;
                 }
                 FD_CLR(fileno(fp), &rset);
                 continue;
@@ -240,7 +239,7 @@ interface_run(FILE* fp, int sockfd, char* cmd)
                 if (ret != 0) {
                     fprintf(stderr, "shutdown failed: %s\n",
                         strerror(errno));
-                    exit(1);
+                    return 1;
                 }
                 FD_CLR(fileno(fp), &rset);
                 continue;
@@ -249,7 +248,7 @@ interface_run(FILE* fp, int sockfd, char* cmd)
             buf[ODS_SE_MAXLINE-1] = '\0';
             if (strncmp(buf, "exit", 4) == 0 ||
                 strncmp(buf, "quit", 4) == 0) {
-                return;
+                return 0;
             }
             ods_str_trim(buf);
             n = strlen(buf);
@@ -263,7 +262,7 @@ interface_run(FILE* fp, int sockfd, char* cmd)
  * Start interface
  *
  */
-static void
+static int
 interface_start(char* cmd)
 {
     int sockfd, ret, flags;
@@ -277,7 +276,7 @@ interface_start(char* cmd)
     if (sockfd < 0) {
         fprintf(stderr, "Unable to connect to engine. "
             "socket() failed: %s\n", strerror(errno));
-        exit(1);
+        return 1;
     }
 
     /* no suprises */
@@ -291,8 +290,7 @@ interface_start(char* cmd)
         sizeof(servaddr));
     if (ret != 0) {
         if (cmd && ods_strcmp(cmd, "start\n") == 0) {
-            ret = system(ODS_SE_ENGINE);
-            return;
+            return system(ODS_SE_ENGINE);
         }
 
         if (cmd && ods_strcmp(cmd, "running\n") == 0) {
@@ -303,7 +301,7 @@ interface_start(char* cmd)
         }
 
         close(sockfd);
-        exit(1);
+        return 1;
     }
 
     /* set socket to non-blocking */
@@ -312,14 +310,14 @@ interface_start(char* cmd)
         ods_log_error("[%s] unable to start interface, fcntl(F_GETFL) "
             "failed: %s", cli_str, strerror(errno));
         close(sockfd);
-        return;
+        return 1;
     }
     flags |= O_NONBLOCK;
     if (fcntl(sockfd, F_SETFL, flags) < 0) {
         ods_log_error("[%s] unable to start interface, fcntl(F_SETFL) "
             "failed: %s", cli_str, strerror(errno));
         close(sockfd);
-        return;
+        return 1;
     }
 
     /* some sort of interface */
@@ -328,9 +326,9 @@ interface_start(char* cmd)
     }
 
     /* run */
-    interface_run(stdin, sockfd, cmd);
+    ret = interface_run(stdin, sockfd, cmd);
     close(sockfd);
-    return;
+    return ret;
 }
 
 
@@ -345,6 +343,7 @@ main(int argc, char* argv[])
     int options_size = 0;
     const char* options[4];
     char* cmd = NULL;
+    int ret = 0;
     allocator_type* clialloc = allocator_create(malloc, free);
     if (!clialloc) {
         fprintf(stderr,"error, malloc failed for client\n");
@@ -380,14 +379,16 @@ main(int argc, char* argv[])
     /* main stuff */
     if (cmd && ods_strcmp(cmd, "-h\n") == 0) {
         usage(stdout);
+        ret = 1;
     } else if (cmd && ods_strcmp(cmd, "--help\n") == 0) {
         usage(stdout);
+        ret = 1;
     } else {
-        interface_start(cmd);
+        ret = interface_start(cmd);
     }
 
     /* done */
     allocator_deallocate(clialloc, (void*) cmd);
     allocator_cleanup(clialloc);
-    return 0;
+    return ret;
 }
