@@ -1,5 +1,5 @@
 /*
- * $Id: confparser.c 6065 2012-01-16 09:45:47Z jerry $
+ * $Id: confparser.c 6256 2012-04-10 14:28:55Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -59,6 +59,7 @@ parse_file_check(const char* cfgfile, const char* rngfile)
     xmlRelaxNGParserCtxtPtr rngpctx = NULL;
     xmlRelaxNGValidCtxtPtr rngctx = NULL;
     xmlRelaxNGPtr schema = NULL;
+    int status = 0;
 
     if (!cfgfile || !rngfile) {
         ods_log_error("[%s] no cfgfile or rngfile", parser_str);
@@ -117,8 +118,6 @@ parse_file_check(const char* cfgfile, const char* rngfile)
         return ODS_STATUS_RNG_ERR;
     }
     /* Validate a document tree in memory. */
-/*
-    better not check: if not correct, this will segfault.
     status = xmlRelaxNGValidateDoc(rngctx,doc);
     if (status != 0) {
         ods_log_error("[%s] cfgfile validation failed %s", parser_str,
@@ -130,7 +129,6 @@ parse_file_check(const char* cfgfile, const char* rngfile)
         xmlFreeDoc(doc);
         return ODS_STATUS_RNG_ERR;
     }
-*/
     xmlRelaxNGFreeValidCtxt(rngctx);
     xmlRelaxNGFree(schema);
     xmlRelaxNGFreeParserCtxt(rngpctx);
