@@ -1,5 +1,5 @@
 /*
- * $Id: keys.c 5380 2011-08-09 21:00:32Z matthijs $
+ * $Id: keys.c 6237 2012-04-03 09:38:16Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -253,7 +253,7 @@ key_log(key_type* key, const char* name)
     if (!key) {
         return;
     }
-    ods_log_debug("[%s] zone %s key: LOCATOR[%s] FLAGS[%u] ALGORITHM[%u] "
+    ods_log_verbose("[%s] zone %s key: LOCATOR[%s] FLAGS[%u] ALGORITHM[%u] "
         "KSK[%i] ZSK[%i] PUBLISH[%i]", key_str, name?name:"(null)", key->locator,
         key->flags, key->algorithm, key->ksk, key->zsk, key->publish);
     return;
