@@ -1,5 +1,5 @@
 /*
- * $Id: signconf.c 5248 2011-06-27 09:29:49Z matthijs $
+ * $Id: signconf.c 6272 2012-04-20 10:25:47Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -178,6 +178,9 @@ signconf_update(signconf_type** signconf, const char* scfile,
     /* is the file updated? */
     st_mtime = ods_file_lastmodified(scfile);
     if (st_mtime <= last_modified) {
+        ods_log_deeebug("[%s] file %s not modified since (file %u, "
+            "mem %u)", sc_str, (unsigned) st_mtime,
+            (unsigned) last_modified);
         return ODS_STATUS_UNCHANGED;
     }
 
@@ -447,6 +450,8 @@ signconf_compare_denial(signconf_type* a, signconf_type* b)
 
            new_task = TASK_NSECIFY;
        }
+   } else if (duration_compare(a->soa_min, b->soa_min)) {
+       new_task = TASK_NSECIFY;
    }
    return new_task;
 }
@@ -755,7 +760,7 @@ signconf_log(signconf_type* sc, const char* name)
             (int) sc->audit);
 
         if (sc->nsec_type == LDNS_RR_TYPE_NSEC3) {
-            ods_log_debug("[%s] zone %s nsec3: OPTOUT[%i] ALGORITHM[%u] "
+            ods_log_info("[%s] zone %s nsec3: OPTOUT[%i] ALGORITHM[%u] "
                 "ITERATIONS[%u] SALT[%s]", sc_str, name, sc->nsec3_optout,
                 sc->nsec3_algo, sc->nsec3_iterations,
                 sc->nsec3_salt?sc->nsec3_salt:"(null)");
