@@ -1,5 +1,5 @@
 /*
- * $Id: zone.c 6197 2012-03-05 14:41:45Z matthijs $
+ * $Id: zone.c 6244 2012-04-03 13:56:27Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -651,6 +651,7 @@ zone_prepare_nsec3(zone_type* zone, int recover)
             ods_log_error("[%s] unable to prepare zone %s for NSEC3: failed "
                 "to create NSEC3PARAM RR", zone_str, zone->name);
             nsec3params_cleanup(zone->nsec3params);
+            zone->nsec3params = NULL;
             return ODS_STATUS_MALLOC_ERR;
         }
         ods_log_assert(nsec3params_rr);
@@ -701,7 +702,7 @@ zone_backup(zone_type* zone)
     ods_log_assert(zone->zonedata);
     ods_log_assert(zone->signconf);
 
-    filename = ods_build_path(zone->name, ".backup", 0);
+    filename = ods_build_path(zone->name, ".backup", 0, 1);
     fd = ods_fopen(filename, NULL, "w");
     free((void*)filename);
 
@@ -786,7 +787,7 @@ zone_recover(zone_type* zone)
     ods_log_assert(zone->signconf);
     ods_log_assert(zone->zonedata);
 
-    filename = ods_build_path(zone->name, ".backup", 0);
+    filename = ods_build_path(zone->name, ".backup", 0, 1);
     fd = ods_fopen(filename, NULL, "r");
     free((void*)filename);
     if (fd) {
@@ -897,7 +898,7 @@ zone_recover(zone_type* zone)
             token = NULL;
         }
         /* zonedata part */
-        filename = ods_build_path(zone->name, ".inbound", 0);
+        filename = ods_build_path(zone->name, ".inbound", 0, 1);
         status = adbackup_read(zone, filename);
         free((void*)filename);
         if (status != ODS_STATUS_OK) {
@@ -979,7 +980,7 @@ zone_recover(zone_type* zone)
         return ODS_STATUS_OK;
     } else {
         /* backwards compatible backup recovery (serial) */
-        filename = ods_build_path(zone->name, ".state", 0);
+        filename = ods_build_path(zone->name, ".state", 0, 1);
         fd = ods_fopen(filename, NULL, "r");
         free((void*)filename);
         if (fd) {
